@@ -5,7 +5,7 @@
 #' @param x A data.frame or data.table
 #' @param y A data.frame or data.table
 #' @param by A character vector of variables to join by. If NULL, the default, the join will do a natural join, using all variables with common names across the two tables.
-#' @param suffix Append created for duplicated column names when using `dt_full_join()`
+#' @param suffix Append created for duplicated column names when using `full_join.()`
 #'
 #' @return A data.table
 #' @export
@@ -14,17 +14,17 @@
 #' df1 <- data.table::data.table(x = c("a","a","a","b","b"), y = 1:5)
 #' df2 <- data.table::data.table(x = c("a","b"), z = 1:2)
 #'
-#' df1 %>% dt_left_join(df2)
-#' df1 %>% dt_inner_join(df2)
-#' df1 %>% dt_right_join(df2)
-#' df1 %>% dt_full_join(df2)
-#' df1 %>% dt_anti_join(df2)
-dt_left_join <- function(x, y, by = NULL) {
-  UseMethod("dt_left_join")
+#' df1 %>% left_join.(df2)
+#' df1 %>% inner_join.(df2)
+#' df1 %>% right_join.(df2)
+#' df1 %>% full_join.(df2)
+#' df1 %>% anti_join.(df2)
+left_join. <- function(x, y, by = NULL) {
+  UseMethod("left_join.")
 }
 
 #' @export
-dt_left_join.default <- function(x, y, by = NULL) {
+left_join..default <- function(x, y, by = NULL) {
   if (!is.data.frame(x) | !is.data.frame(y)) stop("x & y must be a data.frame or data.table")
   if (!is.data.table(x)) x <- as_tidytable(x)
   if (!is.data.table(y)) y <- as_tidytable(y)
@@ -37,19 +37,20 @@ dt_left_join.default <- function(x, y, by = NULL) {
   on_vec <- by_x
   names(on_vec) <- by_y
 
-  all_names <- c(names(x), setdiff(names(y), names(x)))
+  y_names <- names(y)
+  all_names <- c(names(x), y_names[!y_names %in% names(x)])
 
-  as_tidytable(y[x, on = on_vec, allow.cartesian = TRUE][, ..all_names])
+  as_tidytable(setcolorder(y[x, on = on_vec, allow.cartesian = TRUE], all_names))
 }
 
 #' @export
-#' @rdname dt_left_join
-dt_inner_join <- function(x, y, by = NULL) {
-  UseMethod("dt_inner_join")
+#' @rdname left_join.
+inner_join. <- function(x, y, by = NULL) {
+  UseMethod("inner_join.")
 }
 
 #' @export
-dt_inner_join.default <- function(x, y, by = NULL) {
+inner_join..default <- function(x, y, by = NULL) {
   if (!is.data.frame(x) | !is.data.frame(y)) stop("x & y must be a data.frame or data.table")
   if (!is.data.table(x)) x <- as_tidytable(x)
   if (!is.data.table(y)) y <- as_tidytable(y)
@@ -66,13 +67,13 @@ dt_inner_join.default <- function(x, y, by = NULL) {
 }
 
 #' @export
-#' @rdname dt_left_join
-dt_right_join <- function(x, y, by = NULL) {
-  UseMethod("dt_right_join")
+#' @rdname left_join.
+right_join. <- function(x, y, by = NULL) {
+  UseMethod("right_join.")
 }
 
 #' @export
-dt_right_join.default <- function(x, y, by = NULL) {
+right_join..default <- function(x, y, by = NULL) {
   if (!is.data.frame(x) | !is.data.frame(y)) stop("x & y must be a data.frame or data.table")
   if (!is.data.table(x)) x <- as_tidytable(x)
   if (!is.data.table(y)) y <- as_tidytable(y)
@@ -89,26 +90,26 @@ dt_right_join.default <- function(x, y, by = NULL) {
 }
 
 #' @export
-#' @rdname dt_left_join
-dt_full_join <- function(x, y, by = NULL, suffix = c(".x", ".y")) {
-  UseMethod("dt_full_join")
+#' @rdname left_join.
+full_join. <- function(x, y, by = NULL, suffix = c(".x", ".y")) {
+  UseMethod("full_join.")
 }
 
 #' @export
-dt_full_join.default <- function(x, y, by = NULL, suffix = c(".x", ".y")) {
+full_join..default <- function(x, y, by = NULL, suffix = c(".x", ".y")) {
     join_mold(x, y, by = by, suffix = suffix,
               all_x = TRUE, all_y = TRUE)
 
 }
 
 #' @export
-#' @rdname dt_left_join
-dt_anti_join <- function(x, y, by = NULL) {
-  UseMethod("dt_anti_join")
+#' @rdname left_join.
+anti_join. <- function(x, y, by = NULL) {
+  UseMethod("anti_join.")
 }
 
 #' @export
-dt_anti_join.default <- function(x, y, by = NULL) {
+anti_join..default <- function(x, y, by = NULL) {
   if (!is.data.frame(x) | !is.data.frame(y)) stop("x & y must be a data.frame or data.table")
   if (!is.data.table(x)) x <- as_tidytable(x)
   if (!is.data.table(y)) y <- as_tidytable(y)
@@ -124,7 +125,7 @@ dt_anti_join.default <- function(x, y, by = NULL) {
   as_tidytable(x[!y, on = on_vec, allow.cartesian = TRUE])
 }
 
-get_bys <- function(x, y, by) {
+get_bys <- function(x, y, by = NULL) {
 
   if (is.null(by)) {
     by_x <- by_y <- intersect(colnames(x), colnames(y))
@@ -142,6 +143,26 @@ get_bys <- function(x, y, by) {
   list(by_x, by_y)
 }
 
+#' @export
+#' @rdname left_join.
+dt_left_join <- left_join.
+
+#' @export
+#' @rdname left_join.
+dt_inner_join <- inner_join.
+
+#' @export
+#' @rdname left_join.
+dt_right_join <- right_join.
+
+#' @export
+#' @rdname left_join.
+dt_full_join <- full_join.
+
+#' @export
+#' @rdname left_join.
+dt_anti_join <- anti_join.
+
 join_mold <- function(x, y, by = NULL, suffix = c(".x", ".y"), all_x, all_y) {
   if (!is.data.frame(x) | !is.data.frame(y)) stop("x & y must be a data.frame or data.table")
   if (!is.data.table(x)) x <- as_tidytable(x)
