@@ -1,3 +1,8 @@
+# Shortcut to use rlang quoting/unquoting with data.table/base R expressions
+eval_expr <- function(express) {
+  eval_tidy(enexpr(express), env = caller_env())
+}
+
 # Creates a shallow copy to prevent modify-by-reference
 shallow <- function(x, cols = names(x), reset_class = FALSE) {
   stopifnot(is.data.table(x), all(cols %in% names(x)))
@@ -12,3 +17,8 @@ shallow <- function(x, cols = names(x), reset_class = FALSE) {
   ans[]
 }
 
+reduce <- function(.x, .f, ..., .init) {
+  f <- function(x, y) .f(x, y, ...)
+  Reduce(f, .x, init = .init)
+}
+
