@@ -1,3 +1,12 @@
+test_that("empty count.() returns number of rows", {
+  test_df <- data.table(a = 1:3, b = 4:6, c = c("a", "a", "a"), d = c("a", "a", "b"))
+  summary_df <- test_df %>%
+    count.()
+
+  expect_named(summary_df, c("N"))
+  expect_equal(summary_df$N, nrow(test_df))
+})
+
 test_that("empty dt_count() returns number of rows", {
   test_df <- data.table(a = 1:3, b = 4:6, c = c("a", "a", "a"), d = c("a", "a", "b"))
   summary_df <- test_df %>%
@@ -7,10 +16,10 @@ test_that("empty dt_count() returns number of rows", {
   expect_equal(summary_df$N, nrow(test_df))
 })
 
-test_that("dt_count() works on data.frame", {
+test_that("count.() works on data.frame", {
   test_df <- data.frame(a = 1:3, b = 4:6, c = c("a", "a", "a"), d = c("a", "a", "b"))
   summary_df <- test_df %>%
-    dt_count()
+    count.()
 
   expect_named(summary_df, c("N"))
   expect_equal(summary_df$N, nrow(test_df))
@@ -19,17 +28,17 @@ test_that("dt_count() works on data.frame", {
 test_that("dt_count(val) returns group results", {
   test_df <- data.table(a = 1:3, b = 4:6, c = c("a", "a", "a"), d = c("a", "a", "b"))
   summary_df <- test_df %>%
-    dt_count(d)
+    count.(d)
 
   expect_named(summary_df, c("d", "N"))
   expect_equal(summary_df$d, c("a", "b"))
   expect_equal(summary_df$N, c(2, 1))
 })
 
-test_that("dt_count() works with enhanced selection", {
+test_that("count.() works with enhanced selection", {
   test_df <- data.table(a = 1:3, b = 4:6, c = c("a", "a", "a"), d = c("a", "a", "b"))
   summary_df <- test_df %>%
-    dt_count(is.character)
+    count.(is.character)
 
   expect_named(summary_df, c("c", "d", "N"))
   expect_equal(summary_df$c, c("a", "a"))
