@@ -1,4 +1,4 @@
-test_that("can add and drop columns", {
+test_that("dt_ can add and drop columns", {
   df <- data.table(x = 1, y = 2, z = 3)
   df <- df %>%
     dt_select(x, y, -y)
@@ -6,10 +6,18 @@ test_that("can add and drop columns", {
   expect_named(df, c("x"))
 })
 
+test_that("can add and drop columns", {
+  df <- data.table(x = 1, y = 2, z = 3)
+  df <- df %>%
+    select.(x, y, -y)
+
+  expect_named(df, c("x"))
+})
+
 test_that("can add and drop columns w/ data.frame", {
   df <- data.frame(x = 1, y = 2, z = 3)
   df <- df %>%
-    dt_select(x, y, -y)
+    select.(x, y, -y)
 
   expect_named(df, c("x"))
 })
@@ -17,7 +25,7 @@ test_that("can add and drop columns w/ data.frame", {
 test_that("can select a range of columns", {
   df <- data.table(x = 1, y = 2, z = 3)
   df <- df %>%
-    dt_select(x:z)
+    select.(x:z)
 
   expect_named(df, c("x", "y", "z"))
 })
@@ -27,7 +35,7 @@ test_that("can use select helpers", {
                    y_start = 1, end_y = 1,
                    stuff = 1)
   df <- df %>%
-    dt_select(dt_starts_with("x"), dt_ends_with("y"), dt_contains("tuf"))
+    select.(starts_with.("x"), ends_with.("y"), contains.("tuf"))
 
   expect_named(df, c("x_start", "end_y", "stuff"))
 })
@@ -35,7 +43,7 @@ test_that("can use select helpers", {
 test_that("works with predicates", {
   df <- data.table(x = c(1,1,1), y = c(2,2,2), z = c("a", "a", "b"))
   df <- df %>%
-    dt_select(is.numeric)
+    select.(is.numeric)
 
   expect_named(df, c("x", "y"))
 })
