@@ -1,4 +1,4 @@
-test_that("unnesting works with nested data.table", {
+test_that("dt_ unnesting works with nested data.table", {
   start_df <- data.table::data.table(
     a = 1:5,
     b = 11:15,
@@ -15,6 +15,23 @@ test_that("unnesting works with nested data.table", {
   expect_equal(unnest_df$a, start_df$a)
 })
 
+test_that("unnesting works with nested data.table", {
+  start_df <- data.table::data.table(
+    a = 1:5,
+    b = 11:15,
+    c = c(rep("a", 3), rep("b", 2)),
+    d = c(rep("a", 2), rep("b", 3)))
+
+  nest_df <- start_df %>%
+    nest_by.(c, d)
+
+  unnest_df <- nest_df %>%
+    unnest.(data)
+
+  expect_named(unnest_df, c("c","d","a","b"))
+  expect_equal(unnest_df$a, start_df$a)
+})
+
 test_that("unnesting works with nested vector", {
   start_df <- data.table::data.table(
     a = 1:5,
@@ -23,12 +40,12 @@ test_that("unnesting works with nested vector", {
     d = c(rep("a", 2), rep("b", 3)))
 
   nest_df <- start_df %>%
-    dt_group_nest(c, d) %>%
-    dt_mutate(vec_col = dt_map(data, ~ .x %>% dt_pull(a)))
+    nest_by.(c, d) %>%
+    mutate.(vec_col = map.(data, ~ .x %>% pull.(a)))
 
 
   unnest_df <- nest_df %>%
-    dt_unnest_legacy(vec_col)
+    unnest.(vec_col)
 
   expect_named(unnest_df, c("c","d","vec_col"))
   expect_equal(unnest_df$vec_col, c(1,2,3,4,5))
